screen = {
		width = love.graphics.getWidth(),
		height = love.graphics.getHeight()
	}

local array = {}
local cells = {}
local grid = {
		width, height,
		cell_size = 8
	}
local tick = 0
local update_rate = 30 --Updates per second

local show_fps = false
local spawn = true

	
function love.load()
	grid.width = math.floor(screen.width / grid.cell_size)
	grid.height = math.floor(screen.height / grid.cell_size)
	for y=0, grid.height-1 do
		array[y] = {}
		for x=0, grid.width-1 do
			array[y][x] = false
		end
	end
end

function love.update(dt)
	tick = tick + dt
	if tick > (1 / update_rate) then
		if spawn then
			local r = love.math.random(0, grid.width)
			array[0][r] = true
		end
		spawn = not spawn	
		
		cells = {}
		for y=0, grid.height-1 do
			for x=0, grid.width-1 do
				if array[y][x] then
					cells[#cells + 1] = {
							x = x,
							y = y
						}
				end
			end
		end
		if #cells > 0 then
			for i,v in ipairs(cells) do
				if (v.y + 1) < grid.height then
					if not array[v.y + 1][v.x] then
						array[v.y][v.x] = false
						array[v.y + 1][v.x] = true
					end
				end
			end
		end
		
		tick = 0
	end

end

function love.draw()
	for y=0, grid.height-1 do
		for x=0, grid.width-1 do
			love.graphics.setColor(0, 32, 64)
			if array[y][x] then
				love.graphics.setColor(255, 255, 255)
			end
			love.graphics.rectangle("fill", x * grid.cell_size, y * grid.cell_size, grid.cell_size-1, grid.cell_size-1)
		end
	end
	if show_fps then
		love.graphics.setColor(180, 0, 0)
		love.graphics.print(love.timer.getFPS(), 12, 12)
	end
end

function love.keypressed(key)
	if key == "escape" then love.event.push("quit") end
	if key == "tab" then show_fps = not show_fps end
end